@@ -1,7 +1,7 @@
 package Acme::MyFirstModule::MCMILLHJ;
 
 use 5.006;
-use strict
+use strict;
 use warnings;
 
 =head1 NAME
@@ -14,7 +14,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
